@@ -9,12 +9,11 @@
 #rm ./*.log
 
 TOP_DIR=`pwd`
-NS3VER=3.12.1
+NS3VER=3.13
 NS3_DIR=$TOP_DIR/`ls -d ns-*`
 PYBINDGENV_DIR=$TOP_DIR/`ls -d pybindgen-0.*`
 NSC_DIR=$TOP_DIR/`ls -d nsc-*`
 DEBIAN_DIR=$TOP_DIR/debian
-WAF_DIR=$DEBIAN_DIR/`cd $DEBIAN_DIR;ls -d waf-*`
 
 echo $DEBIAN_DIR
 
@@ -23,22 +22,24 @@ echo $DEBIAN_DIR
 cd $TOP_DIR
 rm .config
 rm *.pyc
-cp debian/upstream-back/build.py build.py
+
+##############################################
+# build waf
+cd $DEBIAN_DIR/waf-1.6
+./configure
+cp waf $NS3_DIR
+make distclean
+cd $DEBIAN_DIR/waf-1.5
+./configure
+cp waf $PYBINDGENV_DIR
+make distclean
 
 ################################################
 #clean ns3 dir
 cd $NS3_DIR
 
-echo $WAF_DIR
-cd $WAF_DIR
-./configure
-cp waf $NS3_DIR/waf
-make distclean
-rm ./waf
-find . -name '*.pyc' -exec rm {} \;
-cd $NS3_DIR
-
 rm ./doc/introspected-doxygen.h
+rm ./doc/ns3-object.txt
 rm -rf ./doc/html
 rm -rf ./doc/latex
 
@@ -57,12 +58,12 @@ rm ./different.pcap
 rm -rf ./build
 find . -name '*.pyc' -exec rm {} \;
 find . -name '.waf-*' -exec rm -rf {} \;
-
-rm ./waf
+rm waf
 
 cd $PYBINDGENV_DIR
 find . -name '*.pyc' -exec rm {} \;
 find . -name '.waf-*' -exec rm -rf {} \;
+rm waf
 
 cd $NSC_DIR
 ./scons.py -c
